isPart property
bool
get
isPart
Whether the file is a part of another library.
Implementation
bool get isPart => unit.directives.any((d) => d is PartOfDirective);
Whether the file is a part of another library.
bool get isPart => unit.directives.any((d) => d is PartOfDirective);