reportAt method
Reports a violation at the start of entity, a node or token of the
syntax tree, described by message.
Implementation
void reportAt(SyntacticEntity entity, String message) =>
reportOffset(entity.offset, message);
Reports a violation at the start of entity, a node or token of the
syntax tree, described by message.
void reportAt(SyntacticEntity entity, String message) =>
reportOffset(entity.offset, message);