id property
String
get
id
The unique id of the rule in lower snake case, such as no_print. It
is used in the configuration, in ignore comments and in reports.
Implementation
String get id;
The unique id of the rule in lower snake case, such as no_print. It
is used in the configuration, in ignore comments and in reports.
String get id;