builder library
The build_runner builders of Inspectra.
They are applied to the root package automatically once Inspectra is a dev dependency, and do nothing until a feature is enabled in the configuration.
Functions
-
apiBuilder(
BuilderOptions options) → Builder -
Writes the public API dump; see
apiin the configuration. -
formatBuilder(
BuilderOptions options) → Builder -
Checks the formatting when
format.run_on_buildis set. -
licenseScanBuilder(
BuilderOptions options) → Builder -
Runs the license scan when
trivy.license.run_on_buildis set. -
lintBuilder(
BuilderOptions options) → Builder -
Analyzes the package when
lint.run_on_buildis set. -
secretScanBuilder(
BuilderOptions options) → Builder -
Runs the secret scan when
trivy.secret.run_on_buildis set. -
styleBuilder(
BuilderOptions options) → Builder -
Runs the style check when
style.run_on_buildis set. -
vulnerabilityScanBuilder(
BuilderOptions options) → Builder -
Runs the vulnerability scan when
trivy.vulnerability.run_on_buildis set.