StyleReporter class final
Collects the violations one rule finds in one file.
Constructors
- StyleReporter(String ruleId, StyleFile file)
-
Creates a reporter for the rule
ruleIdcheckingfile.
Properties
- file → StyleFile
-
The checked file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ruleId → String
-
The id of the rule that reports.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
violations
→ List<
StyleViolation> -
The reported violations, in the order they were reported.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reportAt(
SyntacticEntity entity, String message) → void -
Reports a violation at the start of
entity, a node or token of the syntax tree, described bymessage. -
reportLine(
int line, String message) → void -
Reports a violation at the start of the one-based
line, described bymessage. -
reportOffset(
int offset, String message) → void -
Reports a violation at the character
offsetof the file, described bymessage. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited